==> kubernetes-model-core-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/ScopedResourceSelectorRequirementBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ScopedResourceSelectorRequirementBuilder extends ScopedResourceSelectorRequirementFluentImpl<ScopedResourceSelectorRequirementBuilder> implements VisitableBuilder<ScopedResourceSelectorRequirement,ScopedResourceSelectorRequirementBuilder> {

    ScopedResourceSelectorRequirementFluent<?> fluent;
    Boolean validationEnabled;

    public ScopedResourceSelectorRequirementBuilder() { 
        this(true);
    }


    public ScopedResourceSelectorRequirementBuilder(Boolean validationEnabled) { 
        this(new ScopedResourceSelectorRequirement(), validationEnabled);
    }


    public ScopedResourceSelectorRequirementBuilder(ScopedResourceSelectorRequirementFluent<?> fluent) { 
        this(fluent, true);
    }


    public ScopedResourceSelectorRequirementBuilder(ScopedResourceSelectorRequirementFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new ScopedResourceSelectorRequirement(), validationEnabled);
    }


    public ScopedResourceSelectorRequirementBuilder(ScopedResourceSelectorRequirementFluent<?> fluent,ScopedResourceSelectorRequirement instance) { 
        this(fluent, instance, true);
    }


    public ScopedResourceSelectorRequirementBuilder(ScopedResourceSelectorRequirementFluent<?> fluent,ScopedResourceSelectorRequirement instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withOperator(instance.getOperator()); 
        fluent.withScopeName(instance.getScopeName()); 
        fluent.withValues(instance.getValues()); 
        this.validationEnabled = validationEnabled; 
    }


    public ScopedResourceSelectorRequirementBuilder(ScopedResourceSelectorRequirement instance) { 
        this(instance,true);
    }


    public ScopedResourceSelectorRequirementBuilder(ScopedResourceSelectorRequirement instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withOperator(instance.getOperator()); 
        this.withScopeName(instance.getScopeName()); 
        this.withValues(instance.getValues()); 
        this.validationEnabled = validationEnabled; 
    }


    public ScopedResourceSelectorRequirement build() {
        ScopedResourceSelectorRequirement buildable = new ScopedResourceSelectorRequirement(fluent.getOperator(),fluent.getScopeName(),fluent.getValues());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ScopedResourceSelectorRequirementBuilder that = (ScopedResourceSelectorRequirementBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/ScopedResourceSelectorRequirementBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ScopedResourceSelectorRequirementBuilder extends ScopedResourceSelectorRequirementFluentImpl<ScopedResourceSelectorRequirementBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<ScopedResourceSelectorRequirement,ScopedResourceSelectorRequirementBuilder> {

    ScopedResourceSelectorRequirementFluent<?> fluent;
    Boolean validationEnabled;

    public ScopedResourceSelectorRequirementBuilder() {
        this(true);
    }

    public ScopedResourceSelectorRequirementBuilder(Boolean validationEnabled) {
        this(new ScopedResourceSelectorRequirement(), validationEnabled);
    }

    public ScopedResourceSelectorRequirementBuilder(ScopedResourceSelectorRequirementFluent<?> fluent) {
        this(fluent, true);
    }

    public ScopedResourceSelectorRequirementBuilder(ScopedResourceSelectorRequirementFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ScopedResourceSelectorRequirement(), validationEnabled);
    }

    public ScopedResourceSelectorRequirementBuilder(ScopedResourceSelectorRequirementFluent<?> fluent,ScopedResourceSelectorRequirement instance) {
        this(fluent, instance, true);
    }

    public ScopedResourceSelectorRequirementBuilder(ScopedResourceSelectorRequirementFluent<?> fluent,ScopedResourceSelectorRequirement instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withOperator(instance.getOperator()); 
        fluent.withScopeName(instance.getScopeName()); 
        fluent.withValues(instance.getValues()); 
        this.validationEnabled = validationEnabled; 
    }

    public ScopedResourceSelectorRequirementBuilder(ScopedResourceSelectorRequirement instance) {
        this(instance,true);
    }

    public ScopedResourceSelectorRequirementBuilder(ScopedResourceSelectorRequirement instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withOperator(instance.getOperator()); 
        this.withScopeName(instance.getScopeName()); 
        this.withValues(instance.getValues()); 
        this.validationEnabled = validationEnabled; 
    }

    public ScopedResourceSelectorRequirement build() {
        ScopedResourceSelectorRequirement buildable = new ScopedResourceSelectorRequirement(fluent.getOperator(),fluent.getScopeName(),fluent.getValues());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ScopedResourceSelectorRequirementBuilder that = (ScopedResourceSelectorRequirementBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
